%% Comment all function calls to output every variable to the workspace.
%% Uncomment the following line for no output of variables to the workspace: 
% function JP_BinWaves()

%% Uncomment the following line to output only H, T, D to the workspace:                                                                                                                                                                                                            
% function [H,T,D] = JP_BinWaves()

%% Uncomment the following lines for only many outputs:                                                                                                                                                                                                              
% function [H,T,D,NWaves,Nperms,N,Hmean,...
%           frequency,frequencyHT,frequencyDH,frequencyTD,...
%           PercentOccurrence,PercentOccurrenceHT,PercentOccurrenceDH,PercentOccurrenceTD] = JP_BinWaves()

%!#################################################################################################################################133! ! Fortran 90/95/2003/2008 ISO max = 132
%=======================================================================================% 
%!======================================================================73! F77 ISO=72 !%
%!**********************************************************************73!            !%
%!                                                                                     !%
%!          *****************************************************                      !%
%!          *                   JP_BinWaves.m                   *                      !%
%!          *                                                   *                      !%
%!          *   Calculates 2-way & 3-way joint probability      *                      !%
%!          *      statistics from directional wave data.       *                      !%
%!          *   Outputs tables of statistics and permutations   *                      !%
%!          *         3-way JP refers to H vs. T vs. Dir        *                      !%
%!          *    2-way JP is H vs. T, Dir vs. H, & T vs. Dir    *                      !%
%!          *                                                   *                      !%
%!          *                         Ken Connell               *                      !%
%!          *                      Rusty Permenter              *                      !%
%!          *                rusty.permenter@erdc.dren.mil      *                      !%
%!          *                                                   *                      !%
%!          *****************************************************                      !%
%!                                                                                     !%
%!                                                                                     !%
%! Calls:  (self contained; no non-intrinsic external functions called                 !%
%!   bar.m (matlab standard intrinsic function): for plotting stacked histogram        !%
%!   surf.m (matlab standard intrinsic function): for plotting 3D Joint Prob.          !%
%!   polar.m (matlab standard intrinsic function): for plotting wave rose              !%
%!                                                                                     !%
%!                                                                                     !%
%! Inputs:                                                                             !%
%!  wavedata_infilename: Wave data file directory path [user-prompted browse dialogue] !%
%!  wavedata_infilename: Wave data file name, including:                               !%
%!           H: Wave Heigth                                                            !% 
%!           T: Wave Period                                                            !% 
%!           D: Wave Direction                                                         !%
%!           <Currently setup for Columns: [3]= Height; [4]= Period; [5]= Direction>   !%
%!                                                                                     !%
%!  H_column: user command prompt input: Enter column number for Wave Height (H)       !%
%!  T_column: user command prompt input: Enter column number for Wave Period (T)       !%
%!  D_column: user command prompt input: Enter column number for Wave Direction (Dir)  !%
%!                                                                                     !%  
%!  bin_edge_method: Input for Definition of Bin Edges [default = method 2]            !%
%!                   <user-input prompted at the on-screen command prompt>             !%
%!          Enter 1: Input band widths then auto-bin between min and max data values   !% 
%!          Enter 2: Input explicit array of bin edges                                 !%
%!                                                                                     !%
%!                                                                                     !%
%!                                                                                     !%
%! Outputs:                                                                            !%
%!  WaveBin_Table.dat: Output 3-way permutation table written to ASCII file, includes: !% 
%!           index: Permutation index written in 'Hbin#Tbin#Dbin#'(ie,'HHTTDD') format !%
%!           Hbin_cntr: Wave Height bin (mid-point or center of bin)                   !%
%!           Tbin_cntr: Wave Period bin (mid-point or center of bin)                   !%
%!           Dbin_cntr: Wave Direction bin (mid-point or center of bin)                !% 
%!           frequency: Frequency of occurrence in counts                              !%
%!           PercentOccurrence: Normalized frequency of Occurrence in percent (%)      !% 
%!                                                                                     !%
%!  JP_HvsT_Table.dat: Output H vs. T probability table to ASCII file, includes:       !% 
%!           Hbin_cntr:   Wave Height bin (mid-point or center of bin)                 !%
%!           Tbin_cntr:   Wave Period bin (mid-point or center of bin)                 !%
%!           frequencyHT: Frequency of H vs. T occurrence in counts                    !%
%!                                                                                     !%
%!  JP_DvsH_Table.dat: Output Dir vs. H probability table to ASCII file, includes:     !% 
%!           Dbin_cntr:   Wave Direction bin (mid-point or center of bin)              !%
%!           Hbin_cntr:   Wave Height bin (mid-point or center of bin)                 !%
%!           frequencyDH: Frequency of Dir vs. H occurrence in counts                  !%
%!                                                                                     !%
%!  JP_TvsD_Table.dat: Output T vs. Dir probability table to ASCII file, includes:     !% 
%!           Tbin_cntr:   Wave Period bin (mid-point or center of bin)                 !%
%!           Dbin_cntr:   Wave Direction bin (mid-point or center of bin)              !%
%!           frequencyTD: Frequency of T vs. Dir occurrence in counts                  !%
%!                                                                                     !%
%!  WaveStats_Table.dat: Output bulk wave statistics table to ASCII file, includes:    !% 
%!           NWaves:     Total Number of Wave Records                                  !%
%!           Nperms:     Number of Wave Bin Permutations                               !%
%!           Hmean:      Average Wave Height                                           !%
%!           Hstdev:     Standard Deviation of Wave Height                             !%
%!           Tmean:      Average Wave Period                                           !%
%!           Tstdev:     Standard Deviation of Wave Period                             !%
%!           Hmax:       Maximum Wave Height                                           !%
%!           TatHmax:    Period Associated w/Max Wave Height                           !%
%!           DatHmax:    Direction Associated w/Max Wave Height                        !%
%!           RecNatHmax: Record Number Associated w/Max Wave Height                    !%
%!  JP_MultipleTimebin_Probability.dat: Wave Permutation Table with Time Distribution  !%
%!                                                                                     !%
%!  Figures: (10 total)                                                                !%
%!           3 2-way 2D Stacked Histogram Plots for:                                   !% 
%!                        1. H vs. T;                                                  !%
%!                        2. Dir; vs. H;                                               !%
%!                        3. T vs. Dir;                                                !%
%!           3 2-way 3D Joint Probability Plots for:                                   !% 
%!                        1. H vs. T (vs. % occurrence on z-axis);                     !%
%!                        2. Dir; vs. H (vs. % occurrence on z-axis);                  !%
%!                        3. T vs. Dir (vs. % occurrence on z-axis);                   !%
%!           1 2-way 2D Stacked Polar Wave Rose Diagram for:                           !% 
%!                        1. Dir; vs. H (vs. % occurrence or frequency on polar axis); !%
%!           3 % Exceedance vs. % Occurrence Plots for:                                !% 
%!                        1. H vs. % Exceedance;                                       !%
%!                        2. T vs. % Exceedance;                                       !%
%!                        3. Dir vs. % Exceedance;                                     !%
%!                                                                                     !%
%!**********************************************************************73!            !%
%!======================================================================73! F77 ISO=72 !%
%=======================================================================================% 
%!#################################################################################################################################133! ! Fortran 90/95/2003/2008 ISO max = 132

% #################################################################################################################################133!
%                  /
%                 <          INPUT  (START)
%                  \
% #################################################################################################################################133!

clear all
clc


%
% =====================================================================73!
%        START: Load ASCII Wave Time Series Data(*.dat)
% =====================================================================73!
%
disp('Select File to Load ASCII Wave Time Series Data(*.dat)...')
% -------------------------------------------------------
[wavedata_infilename,wavedata_inpath] = uigetfile('*.txt','Select ASCII Wave Time Series Data File to Open');
if isequal(wavedata_infilename,0)|isequal(wavedata_inpath,0)
    disp('File not found')
    return %needed if canceled once routine is started
else
    disp(['File ', wavedata_inpath, wavedata_infilename, ' found'])
end
% combine path and file names into one string:
wavedata_infilepathname = strcat(wavedata_inpath, wavedata_infilename);

wavedata_delimiter = input(['\nEnter wave data file column delimiter [space]:\n',...
                      '< > for space, <,> for comma, <\\t> for tab, <enter_delimiter_character(s)_here> for custom:\n\n',...
                      'K>>> '],'s');
wavedata_nheaderlines  = input('\nEnter number of header rows in wave data file [default = 0]: ');

if isempty(wavedata_delimiter)                                                       % If no value is entered, revert to default H column: H=3rd column
   disp('Setting wavedata_delimiter to default space [ ] delimited.');
   wavedata_delimiter =  ' ';
else
    disp('Wave Data File Column Delimiter: '),disp(wavedata_delimiter)
end
if isempty(wavedata_nheaderlines)                                                       % If no value is entered, revert to default T column: T=4th column
   disp('No value entered... Setting wavedata_nheaderlines to default number of header rows [0].');
   wavedata_nheaderlines =  0;
else
   disp('Number of Header Rows in Wave Data File: '),disp(wavedata_nheaderlines)
end

% import data into wavedata_data structure group:
wavedata_data=importdata(wavedata_infilepathname,wavedata_delimiter,wavedata_nheaderlines);
% -------------------------------------------------------

% Prompt user input for column numbers assigned to H, T, and Dir columns:
H_column = input('Enter column number for Significant Wave Height (H): ');
T_column = input('Enter column number for Wave Period (T): ');
D_column = input('Enter column number for Wave Direction (Dir): ');
inputtype=input('Enter input type (1 for NDBC buoy, 2 for WIS Data file):  ');
timebins=input('Enter number of seasonal periods for binning: ')


if isempty(H_column)                                                       % If no value is entered, revert to default H column: H=3rd column
   disp('No value entered... Setting H_column to default H column [3].');
   H_column =  3;
end
if isempty(T_column)                                                       % If no value is entered, revert to default T column: T=4th column
   disp('No value entered... Setting T_column to default T column [4].');
   T_column =  4;
end
if isempty(D_column)                                                       % If no value is entered, revert to default Dir column: D=5th column
   disp('No value entered... Setting D_column to default Dir column [5].');
   D_column =  5;
end
if isempty(inputtype)                                                       % If no value is entered, revert to default H column: H=3rd column
   disp('No value entered... Setting Input Type to default [1].');
   H_column =  1;
end

if isempty(inputtype)                                                       % If no value is entered, revert to default H column: H=3rd column
   disp('No value entered... Setting timebins to default [1].');
   H_column =  1;
end

disp('Wave Height (H) Data Column: '),disp(H_column)
disp('Wave Period (T) Data Column: '),disp(T_column)
disp('Wave Direction (D) Data Column: '),disp(D_column)
disp('Input Type: '),disp(inputtype)
disp('Wave Direction (D) Data Column: '),disp(inputtype)

% Assign Wave Height, Period, and Direction to: H, T, and D variables corresponding to user-input column locations 
if isstruct(wavedata_data)==1                                              % Check if file is was imported as the more complex "structured" format
  H=wavedata_data.data(:,H_column);
  T=wavedata_data.data(:,T_column);
  D=wavedata_data.data(:,D_column);
  if inputtype==1;
  year=wavedata_data.data(:,1);
  month=wavedata_data.data(:,2);
  day=wavedata_data.data(:,3);
  hour=wavedata_data.data(:,4);
  minute=0.*[1:1:length(hour)]';
  second=minute;
  elseif inputtype==2;
      date=wavedata_data.data(:,1);
      date=num2str(date);
      year=str2num(date(:,1:4));
      month=str2num(date(:,5:6));
      day=str2num(date(:,7:8));
      hour=str2num(date(:,9:10));
      minute=str2num(date(:,11:12));
      second=str2num(date(:,13:14));
  end
else                                                                       % Else if file is was imported as the simple matrix format
  H=wavedata_data(:,H_column);
  T=wavedata_data(:,T_column);
  D=wavedata_data(:,D_column);
     if inputtype==1;
     year=wavedata_data(:,1);
     month=wavedata_data(:,2);
     day=wavedata_data(:,3);
     hour=wavedata_data(:,4);
     minute=0.*[1:1:length(hour)]';
     second=minute;
     elseif inputtype==2;
     date=wavedata_data(:,1);
     date=num2str(date);
     year=str2num(date(:,1:4));
     month=str2num(date(:,5:6));
     day=str2num(date(:,7:8));
     hour=str2num(date(:,9:10));
     minute=str2num(date(:,11:12));
     second=str2num(date(:,13:14));
     end
end          
datenumbers=datenum(year,month,day,hour,minute,second);
maxyear=max(year);
minyear=min(year);

% =====================================================================73!
%        END: Wave Time Series Data Loaded and Assigned to H, T, and Dir.
% =====================================================================73!






% =====================================================================73!
%       START Call to linear wave transformation (Snell's Law):
% =====================================================================73!

transform_waves=input('Perform Linear Wave Transformation Routine (Snell''s Law) <Y/[N]>? ', 's'); 

if transform_waves == 'Y' | transform_waves == 'y'                                 % uppercase or lowercase YES
% Re-assign waves to offshore values in order to distinguish input waves from transformed waves:
  H0=H;
  T0=T;
  D0=D;
% Enter depths to transform waves from/to:
  dep0=input('Enter input wave information depth(m): '); 
  disp(' '	)
  dep=input('Enter target wave station depth to transform waves to: '); 
  disp(' ')

% =====================================================================73!
% START Convert Meteorological Convention to Shore Normal Angle Convention:
% =====================================================================73!
 
    ShoreNorm=input('Enter shore normal reference angle (e.g., 270 = west facing coast; 0 = north facing coast; 90 = east facing coast; 180 = south facing coast): '); 
    if isempty(ShoreNorm)                                                % If no slope is entered, revert to calculating m by input depths
       disp('No shore normal angle entered... Setting to default [0]: ');
       ShoreNorm =  0;
    end
    
    % Convert to shore normal reference angle convention:
    Dshorenorm = ShoreNorm-D0;
    
    if Dshorenorm < -180.0;
      Dshorenorm = Dshorenorm+360.0;
    elseif Dshorenorm > 180.0;
      Dshorenorm = Dshorenorm-360.0;
    end

% =====================================================================73!
% END Convert Meteorological Convention to Shore Normal Angle Convention.
% =====================================================================73!
 
% =====================================================================73!
%       START Outlier and Error Checks:
% =====================================================================73!
H(H(1:end)<0)=NaN;                                                         % Convert outliers less than 0 seconds to NaNew[p-0
                                % List Rows where H is greater than 25
  maxHthreshold=input(['\nEnter threshold of maximum wave height:\n',...
                       '(all H values greater than this threshold will be reset to NaN)\n',...
                       'K>>> ']);
  if isempty(maxHthreshold)                                                % If no value is entered, revert to default H threshold: Max H = 25
     disp('No H threshold entered... Setting maxHthreshold to default: [25].');
     maxHthreshold =  25;
  end
                       
  H(H(1:end)>maxHthreshold)=NaN;                                           % Convert outliers greater than maxHthreshold to NaN
  disp(['Wave Heights > ', num2str(maxHthreshold),' have been reset to NaN!']);                        % Warn of outlier H greater than 25



T(T(1:end)<0)=NaN;                                                         % Convert outliers less than 0 seconds to NaN
  maxTthreshold=input(['\nEnter threshold of maximum wave period:\n',...
                       '(all T values greater than this threshold will be reset to NaN)\n',...
                       'K>>> ']);
  if isempty(maxTthreshold)                                                % If no value is entered, revert to default T threshold: Max T = 25
     disp('No T threshold entered... Setting maxTthreshold to default: [25].');
     maxTthreshold =  25;
  end

  T(T(1:end)>maxTthreshold)=NaN;                                           % Convert outliers greater than maxTthreshold to NaN
  disp(['Wave Period > ', num2str(maxTthreshold),' have been reset to NaN!']);                        % Warn of outlier T greater than 25



if Dshorenorm(Dshorenorm(1:end)>90);
%  D(D(1:end)>360)                                                          % List Rows where D is greater than 360
  Dshorenorm(Dshorenorm(1:end)>90)=NaN;                                                     % Convert outliers greater than 360 to NaN
  disp('Wave Angles > 90 have been reset to NaN!');                       % Warn of outlier D greater than 360
end
if Dshorenorm(Dshorenorm(1:end)<-90); 
%  D(D(1:end)<-360)                                                          % List Rows where D is less than negative (-)360
  Dshorenorm(Dshorenorm(1:end)<-90)=NaN;                                                    % Convert outliers less than negative (-)360 to NaN
  disp('Wave Angles <-90 have been reset to NaN!');                       % Warn of outlier D greater than 360
end
% =====================================================================73!
%             END Outlier and Error Checks.
% =====================================================================73!

% =====================================================================73!
%       START Call to linear wave transformation (Snell's Law):
% =====================================================================73!

  disp('Calling Linear Wave Transformation Routine (Snell''s Law)'); 
  disp(' ')
  
  [H,T,D] = linwavetheory(H,T,Dshorenorm,dep0,dep);
  
  disp(' Linear Wave Transformation Routine Successful! Proceeding with calculation on transformed waves...'); %' 
  disp(' ')

else
    % =====================================================================73!
%       START Outlier and Error Checks:
% =====================================================================73!
H(H(1:end)<0)=NaN;                                                         % Convert outliers less than 0 seconds to NaNew[p-0
if H(H(1:end)>25);
  disp('WARNING: there are Wave Heights > 25!');                           % Warn of outlier H greater than 25
%  H(H(1:end)>25)                                                           % List Rows where H is greater than 25
  maxHthreshold=input(['\nEnter threshold of maximum wave height:\n',...
                       '(all H values greater than this threshold will be reset to NaN)\n',...
                       'K>>> ']);
  if isempty(maxHthreshold)                                                % If no value is entered, revert to default H threshold: Max H = 25
     disp('No H threshold entered... Setting maxHthreshold to default: [25].');
     maxHthreshold =  25;
  end
                       
  H(H(1:end)>maxHthreshold)=NaN;                                           % Convert outliers greater than maxHthreshold to NaN
  disp(['Wave Heights > ', num2str(maxHthreshold),' have been reset to NaN!']);                        % Warn of outlier H greater than 25
end


T(T(1:end)<0)=NaN;                                                         % Convert outliers less than 0 seconds to NaN
if T(T(1:end)>25);
  disp('WARNING: there are Wave Periods > 25 s!');                         % Warn of outlier T greater than 25
%  T(T(1:end)>25)                                                          % List Rows where T is greater than 25
  maxTthreshold=input(['\nEnter threshold of maximum wave period:\n',...
                       '(all T values greater than this threshold will be reset to NaN)\n',...
                       'K>>> ']);
  if isempty(maxTthreshold)                                                % If no value is entered, revert to default T threshold: Max T = 25
     disp('No T threshold entered... Setting maxTthreshold to default: [25].');
     maxTthreshold =  25;
  end

  T(T(1:end)>maxTthreshold)=NaN;                                           % Convert outliers greater than maxTthreshold to NaN
  disp(['Wave Period > ', num2str(maxTthreshold),' have been reset to NaN!']);                        % Warn of outlier T greater than 25
end


if Dshorenorm(Dshorenorm(1:end)>90);
  disp('WARNING: there are Wave Angles > 90!');                           % Warn of outlier D greater than 360
%  D(D(1:end)>360)                                                          % List Rows where D is greater than 360
  Dshorenorm(Dshorenorm(1:end)>90)=NaN;                                                     % Convert outliers greater than 360 to NaN
  disp('Wave Angles > 90 have been reset to NaN!');                       % Warn of outlier D greater than 360
end
if Dshorenorm(Dshorenorm(1:end)<-90); 
  warning('WARNING: there are Wave Angles < -90!');                       % Warn of outlier D less than negative (-)360
%  D(D(1:end)<-360)                                                          % List Rows where D is less than negative (-)360
  Dshorenorm(Dshorenorm(1:end)<-90)=NaN;                                                    % Convert outliers less than negative (-)360 to NaN
  disp('Wave Angles <-90 have been reset to NaN!');                       % Warn of outlier D greater than 360
end
% =====================================================================73!
%             END Outlier and Error Checks.
% =====================================================================73!% elseif NO transformation [Default]
  disp('No wave transformation from buoy to nearshore location. Proceeding with calculation on input waves... ')
  disp(' ')
end
% =====================================================================73!
%       END Call to linear wave transformation (Snell's Law):
% =====================================================================73!







% =====================================================================73!
%       START Calculate statistics on input wave time series data:
% =====================================================================73!

% define total number of input wave records:
NWaves = length(H);


% Calculate statistics on input wave time series data:
Hmean= mean(H(~isnan(H)));                                                             % average wave height
Hstdev=std(H(~isnan(H)));                                                             % standard deviation of wave height
Tmean=mean(T(~isnan(T)));                                                             % average wave period
Tstdev=std(T(~isnan(T)));                                                             % standard deviation of wave period
                                                                           
Hmax=max(H);                                                               % maximum wave height
TatHmax=T(H==max(H));                                                      % Period associated w/maximum wave height
DatHmax=D(H==max(H));                                                      % Direction associated w/maximum wave height
RecNatHmax=find(H==max(H));                                                % Record Number (i.e., row) where maximum wave height occurs

Tmax=max(T);                                                        % maximum wave period

Dmax=max(D);                                                        % maximum wave direction
Dmin=min(D);                                                        % minimum wave direction

% pre-allocate index counter:
count=0;  

% =====================================================================73!
%       END Calculate statistics on input wave time series data:
% =====================================================================73!
               

% =====================================================================73!
%             START User Input for Definition of Bin Edges:
% =====================================================================73!
% define bin edge arrays (user input):

bin_edge_method = input(['\nEnter input method to define bin edges (Input  <[1], 2>):\n\n' ,...                  
        'Input band widths; Enter 1:\n' ,...  
        'Input explicit array of bin edges; Enter 2:\n\n' ,...  
        'K>>> ']);             
if isempty(bin_edge_method);                                               % If no value is entered, revert to default method case 1:
   disp('No value entered... Setting bin_edge_method to default input method [1].')
   bin_edge_method = 1;
end
 
switch bin_edge_method;
     case 1                                                                 % If method to input band widths and min and max bin edges; Method 2 is entered:
        dHbin = input('\nEnter user-specified wave height band width (e.g., 0.5) : ');
        dTbin = input('Enter user-specified wave period band width (e.g., 2) : ');
        dDbin = input('Enter user-specified wave angle band width (e.g., 10) : ');
        
        % Calculated bin edges:
        Hbin_edge =[0:dHbin:ceil(Hmax./dHbin).*dHbin]; 
        Tbin_edge =[0:dTbin:ceil(Tmax./dTbin).*dTbin];  
        if Dmin <0;
        Dbin_edge =[Dmin:dDbin:(ceil((Dmax-Dmin)/dDbin).*dDbin+Dmin)];
        else
        Dbin_edge =[Dmin:dDbin:ceil(Dmax./dDbin).*dDbin];
        end
        
    case 2                                                                 % If method to input explicit array of bin edges; Method 3 is entered:
        Hbin_edge = input('\nEnter array of user-specified wave height bin edges (e.g., [0 0.5 1 1.5 2 2.5 3 ]) : ');
        Tbin_edge = input('Enter array of user-specified wave period bin edges (e.g., [2 4 6 8 10 12 14 16 18]) : '); 
        Dbin_edge = input('Enter array of user-specified wave direction bin edges (e.g., [-90 -80 -70 -60 -50 -40 -30 -20 -10 0 10 20 30 40 50 60 70 80 90]) : ');
        % Calculated band widths: 
        dHbin = Hbin_edge(2)-Hbin_edge(1); 
        dTbin = Tbin_edge(2)-Tbin_edge(1);
        dDbin = abs(Dbin_edge(2)-Dbin_edge(1));

    otherwise                                                              % If some other value besides 1, 2, or 3 is entered:
        warning('\nUnexpected method to define bin edges. Default bin edges applied:');
        Hbin_edge = [0 0.5 1 1.5 2 2.5 3 ];                                % example case definition of bin edges 
        Tbin_edge = [2 4 6 8 10 12 14 16 18];
        Dbin_edge = [-90 -80 -70 -60 -50 -40 -30 -20 -10 0 10 20 30 40 50 60 70 80 90];
        % Calculated band widths: 
        dHbin = Hbin_edge(2)-Hbin_edge(1); 
        dTbin = Tbin_edge(2)-Tbin_edge(1);
        dDbin = abs(Dbin_edge(2)-Dbin_edge(1));
        
end        %! end switch bin_edge_method


disp('Wave Height (H) Bin Edges: '),disp(Hbin_edge)
disp('Wave Period (T) Bin Edges: '),disp(Tbin_edge)
disp('Wave Direction (D) Bin Edges: '),disp(Dbin_edge)
disp('Wave Height (H) Band Width: '),disp(dHbin)
disp('Wave Period (T) Band Width: '),disp(dTbin)
disp('Wave Direction (D) Band Width: '),disp(dDbin)

% =====================================================================73!
%             END User Input for Definition of Bin Edges:
% =====================================================================73!


disp('Defining bin center arrays...')
% define bin center arrays:
Hbin_cntr = [mean([Hbin_edge(1:end-1);Hbin_edge(2:end)])];
Tbin_cntr = [mean([Tbin_edge(1:end-1);Tbin_edge(2:end)])];
Dbin_cntr = [mean([Dbin_edge(1:end-1);Dbin_edge(2:end)])]; 

disp('Calculating number of bins...')
% define number of bins:
NHbins = length(Hbin_cntr);
NTbins = length(Tbin_cntr);    
NDbins = length(Dbin_cntr);      


% define total number of permutations:
Nperms = NHbins*NTbins*NDbins;
disp('Total number of wave bin permutations: '),disp(Nperms)
% #################################################################################################################################133!
%                                                 \
%                            INPUT  (END)          >
%                                                 /
% #################################################################################################################################133!





% #################################################################################################################################133!
%                  /
%                 <          MAIN  (START)
%                  \
% #################################################################################################################################133!

% disp('type return')
% keyboard
disp('START Main Calculation Loop for binning data by frequency of occurrence... ')
disp('...')
disp('...')
disp('...')
%tic  % temporary computation time calculator START:
% =====================================================================73!
%             START Main Calculation Loop:
% =====================================================================73!

maxyear=max(year);
minyear=min(year);
timeyears=[minyear:1:maxyear];

for i=1:timebins;
    for j=1:length(timeyears);        
        
        beginning(i,j)=((datenum(timeyears(j),1,1,0,0,0)+(i-1)*sum(eomday(timeyears(j),1:12))/timebins));
        last(i,j)=((datenum(timeyears(j),1,1,0,0,0)+(i)*sum(eomday(timeyears(j),1:12))/timebins));
        testing(i,j,1:length(H))=((datenumbers>=beginning(i,j))&(datenumbers<last(i,j)));
       
    end
end
beginning(1,1)=beginning(1,1)-1;
last(end,end)=last(end,end)+1;
for i=1:timebins;
    for j=1:length(timeyears);        
        testing(i,j,1:length(H))=((datenumbers>=beginning(i,j))&(datenumbers<last(i,j)));
       
    end
end
newtest(:,:)=sum(testing,2);
       
 for iwavH = 1:NHbins;                                                        
   for iwavT = 1:NTbins;                                                      
     for iwavD = 1:NDbins;                                                    
                                                             
% -----Conditional Binning START ---------------------------------------   
       if iwavH==NHbins;
       binH=(H(1:end)>=Hbin_edge(iwavH) & H(1:end)<=Hbin_edge(iwavH+1));    % Wave Height (H) bins
       else
       binH=(H(1:end)>=Hbin_edge(iwavH) & H(1:end)<Hbin_edge(iwavH+1));    % Wave Height (H) bins           
       end
       if iwavT==NTbins;
       binT=(T(1:end)>=Tbin_edge(iwavT) & T(1:end)<=Tbin_edge(iwavT+1));    % Wave Period (T) bins
       else
       binT=(T(1:end)>=Tbin_edge(iwavT) & T(1:end)<Tbin_edge(iwavT+1));    % Wave Period (T) bins
       end
       if iwavD==NDbins;
       binD=(D(1:end)>=Dbin_edge(iwavD) & D(1:end)<=Dbin_edge(iwavD+1));
       else
       binD=(D(1:end)>=Dbin_edge(iwavD) & D(1:end)<Dbin_edge(iwavD+1));
       end   
       
       % Wave Direction (D) bins  
% -----Conditional Binning END------------------------------------------   
       
       % Identify records that satisfy 3-way Joint Probability criteria:  
       bintable = (binH + binT + binD);     
       
       % Generate 3-way Joint Probability Permutation Table:                                                                  
       count=count+1;                                                      % Permutation counter; 1:Nperms        
       frequency(count,:)=sum(bintable==3);                                % find wave events that satisfy all 3 bin conditions
       
    %Time Step Binning
   for i=1:timebins;
       newtest2(i,:)=newtest(i,:)+bintable';
   end   
   
   numberoccurrence(count,:)=sum(newtest2==4,2);
       
                                                                               
       % Identify records that satisfy 2-way Joint Probability criteria:   
       bintableHT = (binH + binT);
       bintableDH = (binD + binH);
       bintableTD = (binT + binD);
	     
       % Generate 2-way Joint Probability Tables:                                                                      
       frequencyHT(iwavH,iwavT)=sum(bintableHT==2);                        % find wave events that satisfy 2 bin conditions; Joint Probability Table H vs. T
       frequencyDH(iwavD,iwavH)=sum(bintableDH==2);                        % find wave events that satisfy 2 bin conditions; Joint Probability Table Dir vs. H 
       frequencyTD(iwavT,iwavD)=sum(bintableTD==2);                        % find wave events that satisfy 2 bin conditions; Joint Probability Table T vs. Dir
%       frequencyTD(iwavD,iwavT)=sum(bintableTD==2);                        % find wave events that satisfy 2 bin conditions; Joint Probability Table Dir vs. T (if Dir vs. T is preferred over T vs. Dir, uncomment this line and comment line above)


       index(count,:)= (iwavH*10000 + iwavT*100 + iwavD);                  % generate "index" column for output table: HnTnDn
       
       
       
       OutputTable(count,:)= [Hbin_cntr(iwavH),Tbin_cntr(iwavT),Dbin_cntr(iwavD)]; % write output table                                          
     end                                                                     
   end 
 end                         % enddo each wave condition                     
numberoccurrence=100.*numberoccurrence./length(H);
% =====================================================================73!
%             END Main Calculation Loop:
% =====================================================================73!
disp('END Main Calculation Loop for binning data by frequency of occurrence! ')
%toc  % temporary computation time calculator END: 


% #################################################################################################################################133!
%                                                \ 
%                            MAIN  (END)          >
%                                                / 



% #################################################################################################################################133!
%                  /
%                 <          OUTPUT  (START)
%                  \
% #################################################################################################################################133!
disp('Writing output tables... ')
% =====================================================================73!
%               Output Permutation Table:
% =====================================================================73!

% Calculate percent occurrence:
PercentOccurrence=(frequency/NWaves)*100;
PercentOccurrenceHT=(frequencyHT/NWaves)*100;
PercentOccurrenceDH=(frequencyDH/NWaves)*100;
PercentOccurrenceTD=(frequencyTD/NWaves)*100;

% Develop table for output:
OutputTable=[index,OutputTable,frequency,PercentOccurrence];               % add columns to complete output table: index, Hbin_cntr, Tbin_cntr, Dbin_cntr, frequency,  % Occurrence

%%

% Write ASCII output table:
fileID = fopen('WaveBin_Table.dat','w');
  hdrstr=['Index ','WaveHeight ','Period ','Direction ','Frequency ','% Occurrence '];
  fprintf(fileID,'%s',hdrstr);
  fprintf(fileID,'\n');%carriage return
  prdata = [OutputTable(:,1),OutputTable(:,2),OutputTable(:,3),OutputTable(:,4),OutputTable(:,5),OutputTable(:,6)]';
  fprintf(fileID,'%06i %6.2f %8.2f %8.2f %7.0f %12.2f\n',prdata);  
fclose(fileID);

minCountThreshold = input('Enter minimum count (occurrence) threshold to consider for output table <[1]>: ');
if isempty(minCountThreshold);                                               % If no value is entered, revert to default method case 1:
   minCountThreshold = 1;
end
OutputTableOverThresh = OutputTable(OutputTable(:,5) >= minCountThreshold,:);
NpermsOverThresh = length(OutputTableOverThresh);

% Write ASCII output table:
fileID = fopen('WaveBin_Table_Over_MinCount_Threshold.dat','w');
  hdrstr=['Index ','WaveHeight ','Period ','Direction ','Frequency ','% Occurrence '];
  fprintf(fileID,'%s',hdrstr);
  fprintf(fileID,'\n');%carriage return
  prdata = [OutputTableOverThresh(:,1),OutputTableOverThresh(:,2),OutputTableOverThresh(:,3),OutputTableOverThresh(:,4),OutputTableOverThresh(:,5),OutputTableOverThresh(:,6)]';
  fprintf(fileID,'%06i %6.2f %8.2f %8.2f %7.0f %12.2f\n',prdata);  
fclose(fileID);


% ---------------------------------------------------------------------       
%         Develop H vs. T table for output:
% ---------------------------------------------------------------------
OutputTableHT=[(Hbin_cntr'),frequencyHT];                                  % add columns to complete output table: Hbin_cntr, frequencyHT'
       
       
% Write ASCII output H vs. T table:
fileID = fopen('JP_HvsT_Table.dat','w');
  hdrstrHT1=['                                Wave Period             '];
  hdrstrHT2=['                  ',num2str(Tbin_cntr,'%10.2f')];
  hdrstrHT3=['Wave Height'];
  fprintf(fileID,'%s',hdrstrHT1);
  fprintf(fileID,'\n');%carriage return
  fprintf(fileID,'%s',hdrstrHT2);
  fprintf(fileID,'\n');%carriage return
  fprintf(fileID,'%s',hdrstrHT3);
  fprintf(fileID,'\n');%carriage return
  prdata = OutputTableHT';
  fprintf(fileID,['%6.2f %14i', repmat('%10i',1,NTbins-1),'\n'],prdata); 
fclose(fileID);




%         Develop Percent occurrence file for CMS2MAP:
% ---------------------------------------------------------------------
OutputTableHT=[(Hbin_cntr'),frequencyHT];                                  % add columns to complete output table: Hbin_cntr, frequencyHT'
       
       
% Write ASCII Percent occurrence File:

fileID = fopen('JP_MultipleTimebin_probability.dat','w');
stringformat=' '; for i=1:size(numberoccurrence,2); stringformat=[stringformat ' %f'];end
stringformat=[stringformat '\n']
fprintf(fileID,stringformat,numberoccurrence(OutputTable(:,5) > minCountThreshold,:)'); 
fclose(fileID);
% ---------------------------------------------------------------------
%         Develop D vs. H table for output:
% ---------------------------------------------------------------------
OutputTableDH=[(Dbin_cntr'),frequencyDH];                                  % add columns to complete output table: Dbin_cntr, frequencyDH'
       
       
% Write ASCII output D vs. H  table:
fileID = fopen('JP_DvsH_Table.dat','w');
  hdrstrDH1=['                                Wave Height             '];
  hdrstrDH2=['                  ',num2str(Hbin_cntr,'%10.2f')];
  hdrstrDH3=['Wave Direction'];
  fprintf(fileID,'%s',hdrstrDH1);
  fprintf(fileID,'\n');%carriage return
  fprintf(fileID,'%s',hdrstrDH2);
  fprintf(fileID,'\n');%carriage return
  fprintf(fileID,'%s',hdrstrDH3);
  fprintf(fileID,'\n');%carriage return
  prdata = OutputTableDH';
  fprintf(fileID,['%6.2f %14i', repmat('%10i',1,NHbins-1),'\n'],prdata); 
fclose(fileID);


% ---------------------------------------------------------------------
%         Develop T vs. D table for output:
% ---------------------------------------------------------------------
OutputTableTD=[(Tbin_cntr'),frequencyTD];                                  % add columns to complete output table: Tbin_cntr, frequencyTD'
       
       
% Write ASCII output T vs. D  table:
fileID = fopen('JP_TvsD_Table.dat','w');
  hdrstrTD1=['                                Wave Direction          '];
  hdrstrTD2=['                  ',num2str(Dbin_cntr,'%10.2f')];
  hdrstrTD3=['Wave Period'];
  fprintf(fileID,'%s',hdrstrTD1);
  fprintf(fileID,'\n');%carriage return
  fprintf(fileID,'%s',hdrstrTD2);
  fprintf(fileID,'\n');%carriage return
  fprintf(fileID,'%s',hdrstrTD3);
  fprintf(fileID,'\n');%carriage return
  prdata = OutputTableTD';
  fprintf(fileID,['%6.2f %14i', repmat('%10i',1,NDbins-1),'\n'],prdata); 
fclose(fileID);



% =====================================================================73!
%               Output Wave Statistics Table:
% =====================================================================73!


% Write ASCII output T vs. D  table:
fileID = fopen('WaveStats_Table.dat','w');
  hdrstrStat=['                                Wave Statistics        '];
  fprintf(fileID,'%s',hdrstrStat);
  fprintf(fileID,'\n');                                                    % carriage return
  fprintf(fileID,'%s','Total Number of Wave Records:                  ');    
  fprintf(fileID,'%10i\n',NWaves);                                         % carriage return          
  fprintf(fileID,'%s','Number of Wave Bin Permutations:               ');    
  fprintf(fileID,'%10i\n',Nperms);                                         % carriage return          
  fprintf(fileID,'%s','Average Wave Height:                           ');    
  fprintf(fileID,'%10.2f\n',Hmean);                                        % carriage return          
  fprintf(fileID,'%s','Standard Deviation of Wave Height:             ');    
  fprintf(fileID,'%10.2f\n',Hstdev);                                       % carriage return
  fprintf(fileID,'%s','Average Wave Period:                           ');    
  fprintf(fileID,'%10.2f\n',Tmean);                                        % carriage return
  fprintf(fileID,'%s','Standard Deviation of Wave Period:             ');    
  fprintf(fileID,'%10.2f\n',Tstdev);                                       % carriage return
  fprintf(fileID,'%s','Maximum Wave Height:                           ');    
  fprintf(fileID,'%10.2f\n',Hmax);                                         % carriage return
  fprintf(fileID,'%s','Period Associated w/Max Wave Height:           ');    
  fprintf(fileID,[repmat('%10.2f',1,length(TatHmax)),'\n'],TatHmax);       % carriage return
  fprintf(fileID,'%s','Direction Associated w/Max Wave Height:        ');
  fprintf(fileID,[repmat('%10.2f',1,length(DatHmax)),'\n'],DatHmax);       % carriage return
  fprintf(fileID,'%s','Record Number Associated w/Max Wave Height:    ');    
  fprintf(fileID,[repmat('%10i',1,length(RecNatHmax)),'\n'],RecNatHmax);   % carriage return
fclose(fileID);

%%

% #################################################################################################################################133!
%                                                  \ 
%                            OUTPUT  (END)          >
%                                                  / 
% #################################################################################################################################133!





% #################################################################################################################################133!
%                  /
%                 <          PLOT WAVE JOINT PROBABILITY FIGURES  (START)
%                  \
% #################################################################################################################################133!
disp('Plotting Figures... ')

% =====================================================================73!
%               Plot Stacked Histogram H vs. T:
% =====================================================================73!
figure
  bar(Hbin_cntr,frequencyHT,'stacked','BarWidth',1);
    x = min(Hbin_edge):dHbin: max(Hbin_edge);
    set(gca,'XTick',x,'XTickLabel',x,...
           'FontName','Arial','FontSize',12);
    axis([min(Hbin_edge)  max(Hbin_edge) 0  round(sum(max(frequencyHT)))]);
    legend(num2str(Tbin_cntr'),'Location','Best');                         % 'adds legend of wave height bins
    set(get(legend,'title'),'string','Wave Period Bins','FontName','Arial','FontWeight','bold','FontSize',14);
    xlabel('Wave Height (m)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Count','FontName','Arial','FontWeight','bold','FontSize',14);


% =====================================================================73!
%               Plot Stacked Histogram Dir vs. H:
% =====================================================================73!
figure
  bar(Dbin_cntr,frequencyDH,'stacked','BarWidth',1);
    x = min(Dbin_edge):dDbin: max(Dbin_edge);
    set(gca,'XTick',x,'XTickLabel',x,...
           'FontName','Arial','FontSize',12);
    axis([min(Dbin_edge)  max(Dbin_edge) 0  round(sum(max(frequencyDH)))]);
    legend(num2str(Hbin_cntr'),'Location','Best');                         %' adds legend of wave height bins
    set(get(legend,'title'),'string','Wave Height Bins','FontName','Arial','FontWeight','bold','FontSize',14);
    xlabel('Wave Direction (deg.)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Count','FontName','Arial','FontWeight','bold','FontSize',14);


% =====================================================================73!
%               Plot Stacked Histogram T vs. Dir:
% =====================================================================73!
figure
  bar(Tbin_cntr,frequencyTD,'stacked','BarWidth',1);
    x = min(Tbin_edge):dTbin: max(Tbin_edge);
    set(gca,'XTick',x,'XTickLabel',x,...
           'FontName','Arial','FontSize',12);
    axis([min(Tbin_edge)  max(Tbin_edge) 0  round(sum(max(frequencyTD)))]);
    legend(num2str(Dbin_cntr'),'Location','Best');                         %' adds legend of wave height bins
    set(get(legend,'title'),'string','Wave Direction Bins','FontName','Arial','FontWeight','bold','FontSize',14);
    xlabel('Wave Period (s)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Count','FontName','Arial','FontWeight','bold','FontSize',14);




% =====================================================================73!
%               Plot 3D Joint Probability of H vs. T:
% =====================================================================73!
figure        
  surf(Tbin_cntr, Hbin_cntr, PercentOccurrenceHT,'FaceColor','interp','FaceLighting','phong');
    map=jet(256);
    map(1,:)=1;
    colormap(map);
    colorbar;
    
    zmax=max(max(PercentOccurrenceHT))+round(max(max(PercentOccurrenceHT))*0.10);
    axis([ Tbin_cntr(1) Tbin_cntr(length(Tbin_cntr)) Hbin_cntr(1) Hbin_cntr(length(Hbin_cntr)) 0 round(max(max(PercentOccurrenceHT)))]);
    % xlabel('Wave Height(m)','FontName','Arial','FontWeight','bold','FontSize',14,'Rotation',10);
    % ylabel('Wave Direction(deg.)','FontName','Arial','FontWeight','bold','FontSize',14,'Rotation',-28);
    xlabel('Wave Period (s)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Wave Height(m)','FontName','Arial','FontWeight','bold','FontSize',14);
    zlabel('% Occurrence','FontName','Arial','FontWeight','bold','FontSize',14);


% =====================================================================73!
%               Plot 3D Joint Probability of Dir vs. H:
% =====================================================================73!
figure        
  surf(Hbin_cntr, Dbin_cntr, PercentOccurrenceDH,'FaceColor','interp','FaceLighting','phong');
    map=jet(256);
    map(1,:)=1;
    colormap(map);
    colorbar;
    
    zmax=max(max(PercentOccurrenceDH))+round(max(max(PercentOccurrenceDH))*0.10);
    axis([ Hbin_cntr(1) Hbin_cntr(length(Hbin_cntr)) Dbin_cntr(1) Dbin_cntr(length(Dbin_cntr)) 0 round(max(max(PercentOccurrenceDH)))]);
    xlabel('Wave Height(m)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Wave Direction(deg.)','FontName','Arial','FontWeight','bold','FontSize',14);
    zlabel('% Occurrence','FontName','Arial','FontWeight','bold','FontSize',14);


% =====================================================================73!
%               Plot 3D Joint Probability of T vs. Dir:
% =====================================================================73!
figure        
  surf(Dbin_cntr, Tbin_cntr, PercentOccurrenceTD,'FaceColor','interp','FaceLighting','phong');
    map=jet(256);
    map(1,:)=1;
    colormap(map);
    colorbar;
    
    zmax=max(max(PercentOccurrenceTD))+round(max(max(PercentOccurrenceTD))*0.10);
    axis([ Dbin_cntr(1) Dbin_cntr(length(Dbin_cntr)) Tbin_cntr(1) Tbin_cntr(length(Tbin_cntr)) 0 round(max(max(PercentOccurrenceTD)))]);
    xlabel('Wave Direction (deg.)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Wave Period(s)','FontName','Arial','FontWeight','bold','FontSize',14);
    zlabel('% Occurrence','FontName','Arial','FontWeight','bold','FontSize',14);

% #################################################################################################################################133!
%                                                                       \ 
%                  PLOT WAVE JOINT PROBABILITY FIGURES  (END)            >
%                                                                       / 
% #################################################################################################################################133!





% #################################################################################################################################133!
%                  /
%                 <          PLOT WAVE ROSES  (START)
%                  \
% #################################################################################################################################133!


 
% =====================================================================73!
%               Plot Polar Wave Rose of Dir vs. H:
% =====================================================================73!

%  hcount=hist(D,Dbin_cntr)';                                              %' this is equivalent to the next line: % calulate total number of frequencies for each direction bin

frequencyplottype=input('\nEnter 1 to plot frequency in counts or Enter 2 to plot % Occurrence, [2]: ');

if frequencyplottype==1;
  frequencyplot=frequencyDH;                                               % Counts
  xlabelfreq='Count';                                                      %  xlabel for counts
  disp('Plotting frequency in counts;'),disp('You entered: '),disp(frequencyplottype)          % echo input
else
  frequencyplot=PercentOccurrenceDH;                                       % Occurrence by default
  xlabelfreq='Frequency of occurrence (%)';                                 % xlabel for occurrence
  disp('Plotting frequency in % Occurrence;'),disp('You entered: '),disp(frequencyplottype)          % echo input
end



 hcount=sum(frequencyplot')';                                              %'  calculate total number of frequencies for each direction bin

% Form radius values for histogram triangle
mm=4*NDbins;
r(1:mm,:)=0;
windex1=[2:4:mm];
windex2=[3:4:mm];
r(windex1,:) = hcount;
r(windex2,:) = hcount;

% Form theta values (angles in radians) for histogram triangle from triangle centers (xx)
Dbin_edge_rad = Dbin_edge.*(pi/180);                                       % convert angle bin edges to radians
t = zeros(mm,1);
t(2:4:mm) = Dbin_edge_rad(1:NDbins);
t(3:4:mm) = Dbin_edge_rad(2:NDbins+1);

% Plot the polar rose figure:
figure;
  set(gca,'FontName','Arial','FontSize',12);
  h = polar(t,r,'k');
    set(h,'LineStyle','none');
    set(gca,'FontName','Arial','FontSize',12);
    % rotate 90-deg so that it represents a compass rose; TN = 0-deg & 360-deg
    view(90,-90); 
    % Or to rotate axis to shore normal orientation:
    % view(90-ShoreNorm,-90);
%    cmap = colormap(jet);
    cmap = colormap(jet(NHbins.*10));
    
    % Use the FILL command to color the angle histogram. The following example the fill color is red:
       [xout, yout] = pol2cart(t, r);
       set(gca, 'nextplot', 'add');
       fill(xout, yout, cmap(length(cmap),:));
  

% =====================================================================73!
%              2ND Plot Polar Wave Rose of Dir vs. H:
% =====================================================================73!
    
    hcountsum=hcount;
    
    for i=[NHbins:-1:2];                                                   % for each Wave Height bin: increment bin index backwards (-1) from NHbins to the second bin.
      hcounti=(frequencyplot(:,i)')';                                      %' calculate number of frequencies for each Wave Height bin at each direction bin
      hcounti=(frequencyplot(:,i)')';                                      %' calculate number of frequencies for each Wave Height bin at each direction bin
    
      hcountsum=(hcountsum-hcounti);
    
      % Form radius values for histogram triangle
      r(windex1,:) = hcountsum;
      r(windex2,:) = hcountsum;   
       
      % Plot the additional polar rose fill to H bins:
      hold on;
      [xout, yout] = pol2cart(t, r);
    
    %  colormapping: distribute color map evenly over total number of bins
       cmapRGB =  round((i-1)/NHbins*(length(cmap)));

    % Use the FILL command to color the angle histogram
       fill(xout, yout, cmap(cmapRGB,:));
    end
    
    xlabel('Wave Direction (deg.)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel(  xlabelfreq,'FontName','Arial','FontWeight','bold','FontSize',14);
    
    
    % Create string array for legend 
    Hbin_legend=[(Hbin_cntr(end)):-dHbin:Hbin_cntr(1)]';                   %' Legend string
    Hbin_legend_str=[num2str(Hbin_legend)];                                % Add H, m header w/units
    
    % The following 3 lines turn off the first outline in the legend that was generated from the initial unfilled polar plot  % See: doc Lineseries Properties % (in matlab help)   
    hAnnotation = get(h,'Annotation');
    hLegendEntry = get(hAnnotation,'LegendInformation');
    set(hLegendEntry,'IconDisplayStyle','off')    
        
    % Create legend and legend title
    legend(Hbin_legend_str,'Location','Best');                             %' adds legend of wave height bins to figure
    set(get(legend,'title'),'string','Wave Height Bins','FontName','Arial','FontWeight','bold','FontSize',14);
    

% #################################################################################################################################133!
%                                                                       \ 
%                                       PLOT WAVE ROSES (END)            >
%                                                                       / 
% #################################################################################################################################133!


% #################################################################################################################################133!
%                  /
%                 <          PLOT EXCEEDANCE FIGURES  (START)
%                  \
% #################################################################################################################################133!


% =====================================================================73!
%               Plot % Exceedance of H:
% =====================================================================73!

PercentOccurrenceTotalH=(sum(PercentOccurrenceDH));
for iexceedH=1:NHbins;
  PercentExceedanceTotalH(iexceedH)=(sum(PercentOccurrenceTotalH(:,iexceedH:end)));
end


figure        
  plot(Hbin_cntr, PercentOccurrenceTotalH,'--k',Hbin_cntr, PercentExceedanceTotalH,'r','LineWidth',2);

    x = min(Hbin_edge):dHbin: max(Hbin_edge);
    set(gca,'XTick',x,'XTickLabel',x,...
           'FontName','Arial','FontSize',12);
    axis([min(Hbin_edge)  max(Hbin_edge) 0  100]);
    legend('% Occurrence','% Exceedance' ,'Location','Best');                         %' adds legend of wave height exceedance
    xlabel('Wave Height (m)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Exceedance (%)','FontName','Arial','FontWeight','bold','FontSize',14);

% =====================================================================73!
%               Plot % Exceedance of T:
% =====================================================================73!

PercentOccurrenceTotalT=(sum(PercentOccurrenceHT));
for iexceedT=1:NTbins;
  PercentExceedanceTotalT(iexceedT)=(sum(PercentOccurrenceTotalT(:,iexceedT:end)));
end


figure        
  plot(Tbin_cntr, PercentOccurrenceTotalT,'--k',Tbin_cntr, PercentExceedanceTotalT,'r','LineWidth',2);

    x = min(Tbin_edge):dTbin: max(Tbin_edge);
    set(gca,'XTick',x,'XTickLabel',x,...
           'FontName','Arial','FontSize',12);
    axis([min(Tbin_edge)  max(Tbin_edge) 0  100]);
    legend('% Occurrence','% Exceedance' ,'Location','Best');                         %' adds legend of wave period exceedance
    xlabel('Wave Period (s)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Exceedance (%)','FontName','Arial','FontWeight','bold','FontSize',14);


% =====================================================================73!
%               Plot % Exceedance of Dir:
% =====================================================================73!

PercentOccurrenceTotalD=(sum(PercentOccurrenceTD));
for iexceedD=1:NDbins;
  PercentExceedanceTotalD(iexceedD)=(sum(PercentOccurrenceTotalD(:,iexceedD:end)));
end


figure        
  plot(Dbin_cntr, PercentOccurrenceTotalD,'--k',Dbin_cntr, PercentExceedanceTotalD,'r','LineWidth',2);

    x = min(Dbin_edge):dDbin: max(Dbin_edge);
    set(gca,'XTick',x,'XTickLabel',x,...
           'FontName','Arial','FontSize',12);
    axis([min(Dbin_edge)  max(Dbin_edge) 0  100]);
    legend('% Occurrence','% Exceedance' ,'Location','Best');                         %' adds legend of wave direction exceedance
    xlabel('Wave Direction (deg.)','FontName','Arial','FontWeight','bold','FontSize',14);
    ylabel('Exceedance (%)','FontName','Arial','FontWeight','bold','FontSize',14);


% #################################################################################################################################133!
%                                                                       \ 
%                                       PLOT EXCEEDANCE (END)            >
%                                                                       / 
% #################################################################################################################################133!
